#!/bin/sh

if [ $# != 4 ]; then
    echo "Usage : "$0" (YYMMDD) (Detector ID) (Start No.) (No. of Frames)"
    exit 1
fi

DATE=$1
DETECTOR=$2
IS=$3
N=$4

# Check Architecture
ARCH=`uname`
#uname -a >> $CLLOG

#Start time
if [ $ARCH = "Linux" ]; then
    SECSTART=`date +%s` 
else 
    SECSTART=`date +"%d %H %M %S"| gawk '{print($1*24*3600+$2*3600+$3*60+$4)}'` 
fi

DARK=dark${DETECTOR}.fits

DATAPATH=$DATA/wfcam${DETECTOR}/${DATE}

LDATAPATH=./ldata

if [ ! -d $LDATAPATH ];then
 mkdir $LDATAPATH
fi

case $DETECTOR in 
1) DETECTORC=w ;;
2) DETECTORC=x ;;
3) DETECTORC=y ;;
4) DETECTORC=z ;;
esac

gawk -v path=$DATAPATH -v date=$DATE -v is=$IS -v n=$N -v detector=$DETECTORC 'BEGIN{if(n>0){for(i=is;i<is+n;i++)printf("%s/%s%s_%05d.fit\n",path,detector,date,i)}}' > data.tbl

gawk -v path=$LDATAPATH '{n=split($0,a,"/");print(path"/"a[n])}' data.tbl | sed 's/.fit$/.fits/g' > ldata.tbl
gawk -v path=$LDATAPATH '{n=split($0,a,"/");print(path"/"a[n])}' data.tbl | sed 's/.fit$/.fits[513:1536,513:1536]/g' > ldata-1.tbl

echo imdel @ldata.tbl | cl
paste data.tbl ldata.tbl | gawk '{printf("./bin/fwfcam %s\"[1]\" %s\n",$1,$2)}' | csh
gawk '{printf("hedit %s ctype1 RA ver-\nhedit %s ctype2 DEC ver-\n",$1,$1)}'  ldata.tbl | cl

cat << EOF | cl
 del tmp.dat
 imstati @ldata-1.tbl upper=100 lower=-100 format- > tmp.dat
EOF
gawk '{s+=$3;a[NR]=$3}END{s=s/NR;for(i=1;i<=NR;i++)print(a[i]-s)}' tmp.dat > tmp2.dat

echo imarith @ldata.tbl - @tmp2.dat @ldata.tbl | cl

cat <<EOF | cl
imdel $DARK
imcombine @ldata.tbl $DARK combine=average reject=sigclip
disp $DARK 1 fi+
imdel @ldata.tbl
EOF

echo "Dark frame saved as $DARK"

#END time
if [ $ARCH = "Linux" ] ; then
    SECEND=`date +%s` 
else
    SECEND=`date +"%d %H %M %S"| gawk '{print($1*24*3600+$2*3600+$3*60+$4)}'` 
fi

echo $SECSTART $SECEND | gawk '{printf("Took %d sec to complete\n",$2-$1)}'

